﻿using GalaSoft.MvvmLight;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace WpfApp1_pizza.VM
{
    /*
    * IEnumerable<T> => old-fashioned, not designed for UI
    *     IF the collection doesn't change after setting the DataContext
    * ObservableCollection<T> => for WPF, CollectionChanged event
    *      Notifies the UI when Add/Remove/Clear
    * BindingList<T> => for WPF, ListChanged event
    *      UI notification + event in code if a listitem changes
    */
    class PizzaVM : ObservableObject
    {
        private PizzaExtraVM size;
        public PizzaExtraVM Size
        {
            get { return size; }
            set { Set(ref size, value); RaisePropertyChanged(nameof(TotalPrice)); } // Size=>Price, Logic?
        }
        public BindingList<PizzaExtraVM> Toppings { get; private set; }

        public int TotalPrice // Logic!!! 
        {
            get
            {
                int price = Size.Price;
                foreach (PizzaExtraVM topping in Toppings)
                {
                    if (topping.IsWanted) price += topping.Price;
                }
                return price;
            }
        }

        public PizzaVM()
        {
            Toppings = new BindingList<PizzaExtraVM>();
            Size = new PizzaExtraVM();

            Toppings.ListChanged += (sender, evt) => RaisePropertyChanged(nameof(TotalPrice)); // Toppings=>Price, Logic?
        }
    }
}
